@@ -8,7 +8,7 @@ from file_typer.impl import AddExtensionAction, ProgressBarAction, Walker
 
 table = type_table.TABLE
 
-VERSION = '1.0.12'
+VERSION = '1.0.16'
 
 
 def parse_arguments():
@@ -27,7 +27,7 @@ def parse_arguments():
     parser.add_argument('--version',
                         action='version',
                         version='%(prog)s '+VERSION)
-    parser.add_argument('-D',
+    parser.add_argument('-U',
                         '--dry-run',
                         action='store_true',
                         default=False,
@@ -47,11 +47,6 @@ def parse_arguments():
                         action='store_true',
                         default=False,
                         help='Just copy renamed files, not the entire structure')
-    parser.add_argument('-D',
-                        '--debug',
-                        action='store_true',
-                        default=False,
-                        help='Show info messages')
     parser.add_argument('-o',
                         '--output',
                         action='store',
